/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 2: Standard gravity type regression with exporter-time and importer-time fixed effects for cities and gateways */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table2", replace

qui{
local yearbeg  = "2005" // cutoff years for long-term differences
local yearend  = "2010"

/****************************/
// Load and prepare the data 
/***************************/
/* intercity distances */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) distpg , by(province_code gateway period)
sort province_code gateway period

reshape wide distpg ,i(province_code gateway) j(period)
rename distpg1 distpg

drop distpg0 
sort province_code gateway
save temp.dta,replace

/* construct dependent variable, trade flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR" // trade with Turkish Cyprotic Republic
drop if year==.
collapse (sum) exp imp,by(province gateway year)


destring province_code,replace
destring gateway,replace

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow period)
gen lnvalue=ln(value)

reshape wide value lnvalue,i(province_code gateway flow) j(period)

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)
rename province_code city

egen fes        = group(city flow)     // fixed effects
egen fes2       = group(gateway flow)

/**************/
// Regressions
/**************/
reg2hdfe lnvalue0  lndistpg, id1(fes) id2(fes2) 
estimates store col1
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace
estadd local sample "2003-04" , replace

reg2hdfe lnvalue1  lndistpg, id1(fes) id2(fes2) 
estimates store col2
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace
estadd local sample "2011-12" , replace

xi:ppml value0 i.fes2 i.fes lndistpg
estimates store col3
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "PPML" , replace
estadd local sample "2003-04" , replace

xi:ppml value1 i.fes2 i.fes lndistpg
estimates store col4
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "PPML" , replace
estadd local sample "2011-12" , replace

/**************/
// Results
/**************/
noi esttab col1 col2 col3 col4, compress width(1\hsize) keep(lndistpg) ///
se star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects sample)

/* variable labels for writing to latex */
label variable lndistpg "$\ln dist_{pg}$"
label variable lnvalue0 "$\ln trade_{pg}^f$"
label variable lnvalue1 "$\ln trade_{pg}^f$"
label variable value0 "$\trade_{pg}^f$"
label variable value1  "$\trade_{pg}^f$"

esttab col1 col2 col3 col4 using "table2.tex", replace label compress width(1\hsize) keep(lndistpg) ///
se star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects sample, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "Sample"))
}

log close
translate "Table2.smcl" "Table2.pdf", replace
translate "Table2.smcl" "Table2.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase "Table2.smcl"

