/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 3: baseline results */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table3", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs 
gen RCIV    = (drs-1)*log(distpg) // instrumental variable
keep province_code gateway RCIV 
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) distpg drs  , by(province_code gateway period)
sort province_code gateway period
reshape wide distpg drs ,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs         = drs1-drs0
drop distpg0 drs1
sort province_code gateway
save temp2.dta,replace

/* construct dependent variable, change in trade flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR" // trade with Turkish Cyprotic Republic
drop if year==.
destring province_code,replace
destring gateway,replace
collapse (sum) exp imp,by(province gateway year)
rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) value, by(province_code gateway flow period)
gen lnvalue = ln(value)
reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
drop lnvalue0 lnvalue1 value0 value1
drop if dlnval == .

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if gateway==6 // Exclude Ankara: the only interior 'gateway' city reporting flows; some air shipments and transactions posted to the local customs office but actually going through other border/port cities

gen lndistpg        = ln(distpg)
gen dRC             = lndistpg * (deltadrs)
replace drs0		= drs0-1

rename province_code city
*drop distpg 

egen fes        = group(city flow)    // fixed effects
egen fes2       = group(gateway flow)

/**************/
// Regressions
/**************/
reg2hdfe dlnval deltadrs if distpg!=0, id1(fes) id2(fes2)
estimates store col1
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace

reg2hdfe dlnval dRC, id1(fes) id2(fes2)
estimates store col2
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace

reg2hdfe dlnval dRC deltadrs, id1(fes) id2(fes2)
estimates store col3
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace

xi:ivreg2 dlnval i.fes2 i.fes  (deltadrs= drs0) if distpg!=0, robust first partial(_cons)
estimates store col4
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg dlnval i.fes2 i.fes  (deltadrs= drs0) 
ivendog deltadrs
estadd scalar test_DWH=r(WHF): col4

reg2hdfe dRC RCIV lndistpg, id1(fes) id2(fes2)
estimates store col5f
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "OLS" , replace

xi:ivreg2 dlnval i.fes2 i.fes  (dRC = RCIV lndistpg) , robust first partial(_cons)
estimates store col5
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col5
estadd scalar test_kp=e(widstat): col5
xi:ivreg dlnval i.fes2 i.fes  (dRC = RCIV lndistpg) 
ivendog dRC
estadd scalar test_DWH=r(WHF): col5

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col6
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col6
estadd scalar test_kp=e(widstat): col6
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col6


/**************/
// Results
/**************/
noi esttab col1 col2 col3 col4 col5f col5 col6, compress width(1\hsize) ///
keep(deltadrs dRC  RCIV lndistpg) se /// 
star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects test_ar test_kp  test_DWH)

/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable lndistpg "$\ln dist_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable RCIV "$(\ers_{pg}^{2003}-1)\times \ln dist_{pg}$"

esttab col1 col2 col3  col4 col5f col5 col6 using "table3.tex",replace label compress width(1\hsize) ///
keep(deltadrs dRC  RCIV lndistpg)  /// 
star(* 0.10 ** 0.05 *** 0.01) se ///
s(Regression N r2 FixedEffects test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat."))
}

log close
translate "Table3.smcl" "Table3.pdf",replace
translate "Table3.smcl" "Table3.ps", replace translator(smcl2ps)

capture erase temp.dta
capture erase temp2.dta
capture erase "Table3.smcl"
