/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 4: intensive margin with additional controls */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table4", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs
gen RCIV    = (drs-1)*log(distpg) // instrumental variable
keep province_code gateway RCIV 
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) distpg drs  , by(province_code gateway period)
sort province_code gateway period
reshape wide distpg drs,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs         = drs1-drs0
drop distpg0 
sort province_code gateway
save temp2.dta,replace

/*Gravity estimation to construct the market access and supply access measures */
use "data/data_pgd.dta",clear // trade data at the province-gateway-destination level
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace
keep if year==2003
drop year

collapse (sum) exp imp,by(province gateway )

rename exp value1
rename imp value2
reshape long value, i( province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order  province gate flow
sort  province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow  gateway province
replace value=0 if value==.

collapse (mean) value, by(province_code gateway flow)

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 // Exclude Ankara: the only interior 'gateway' city reporting flows; some air shipments and transactions posted to the local customs office but actually going through other border/port cities

gen lndistpg = ln(distpg)

sort province_code flow
by province_code flow:egen exp_cf=sum(value)
drop if exp_cf==0

egen fes        = group(province_code flow )
egen fes2       = group(gateway flow)

tab fes  , gen(fesdum)
tab fes2 , gen(fes2dum)

/* Get the market access and supply access terms from gravity fixed effects */
ppml value fesdum* fes2dum* lndistpg
gen fe_est_p=. 
for X in num 1/159: replace fe_est_p=_b[fesdumX] if fesdumX==1  
gen fe_est_g=. 
for X in num 1/34: replace fe_est_g=_b[fes2dumX] if fes2dumX==1  

gen ma_pg=(exp(fe_est_g))*(distpg^_b[lndistpg]) 
gen sa_pg=(exp(fe_est_p))*(distpg^_b[lndistpg])

sort province_code
by province_code: egen ma_p=sum(ma_pg)
sort gateway
by gateway: egen sa_g=sum(sa_pg)

gen TP = (ma_p*sa_g)

keep province_code gateway flow TP
sort province_code gateway flow
save temp3.dta,replace

/* construct dependent variable, change in trade flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

collapse (sum) exp imp,by(province gateway year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow period)
gen lnvalue = ln(value)

reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
drop lnvalue0 lnvalue1

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

merge m:1 province_code gateway using "data/routes_gdppc.dta" // change in per capita gdp in cities on the p-g route between 2004-2011
drop if _merge==2
drop _merge

merge m:1 province_code gateway using "data/routes_trade_pre.dta" // total trade of province on the p-g route in 1996 and 2001
drop if _merge==2
drop _merge

sort province_code gateway flow
merge province_code gateway flow  using "temp3.dta"
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg        = ln(distpg)
gen Dtrade9601		= ln(total_trade01)-ln(total_trade96)

gen dRC             = lndistpg * (deltadrs)
gen RCIV2			= lndistpg * (drs0)

su distpg,det
gen Ddist			= distpg>r(p50)

replace total_gdppc=0 if total_gdppc==.
replace Dtrade9601=0 if Dtrade9601==.
gen Dtrade9601lndistpg  = Dtrade9601*lndistpg
gen TPlndistpg          = TP*lndistpg
        
rename province_code city

egen fes        = group(city flow)
egen fes2       = group(gateway flow)

/**************/
// Regressions
/**************/
reg2hdfe dlnval dRC  deltadrs RCIV2 drs0, id1(fes) id2(fes2) // instead IV, use initial ers as a control
estimates store col1
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "OLS" , replace

xi:ivreg2 dlnval i.fes2 i.fes   Ddist  ( dRC deltadrs= RCIV  lndistpg drs0) , robust first partial(_cons)
estimates store col2
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg dlnval i.fes2 i.fes   Ddist  ( dRC deltadrs= RCIV  lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col2

xi:ivreg2 dlnval i.fes2 i.fes Ddist   total_gdppc  ( dRC deltadrs= RCIV  lndistpg drs0) , robust first partial(_cons)
estimates store col3
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg dlnval i.fes2 i.fes Ddist   total_gdppc  ( dRC deltadrs= RCIV  lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col3

xi:ivreg2 dlnval i.fes2 i.fes Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg ( dRC deltadrs= RCIV  lndistpg drs0) , robust first partial(_cons)
estimates store col4
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg dlnval i.fes2 i.fes   Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg  ( dRC deltadrs= RCIV  lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4

xi:ivreg2 dlnval i.fes2 i.fes   Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg TP  TPlndistpg ( dRC deltadrs= RCIV  lndistpg drs0 ) , robust first partial(_cons)
estimates store col5
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col5
xi:ivreg dlnval i.fes2 i.fes   Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg TP  TPlndistpg  ( dRC deltadrs= RCIV  lndistpg drs0 )
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col5


}
/**************/
// Results
/**************/
noi  esttab  col1  col2 col3 col4 col5  ,  compress width(1\hsize) ///
keep(RCIV2 dRC deltadrs drs0 Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg TP TPlndistpg )  /// 
cells("b(fmt(a3) star)" se(par fmt(3)) p(par fmt(4))) star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects test_ar test_kp  test_DWH  )


/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable lndistpg "$\ln dist_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable drs0 "$\ers_{pg}^{2003}$"
label variable RCIV2 "$\ers_{pg}^{2003} \times \ln dist_{pg}$"
label variable total_gdppc "$\Delta \ln PGDP_{pg}^{04-11}$"
label variable Dtrade9601 "$\Delta \ln trade_{pg}^{96-01}$"
label variable TP "$(\MA_p \times SA_g)$"
label variable Ddist "$I_{dist_{pg}>median}$"
label variable Dtrade9601lndistpg "$\Delta \ln trade_{pg}^{96-01}\times \ln dist_{pg}$"
label variable TPlndistpg "$(\MA_p \times SA_g)\times \ln dist_{pg}$"

esttab col1  col2 col3 col4 col5 using "table4.tex",replace label compress width(1\hsize) ///
keep( RCIV2 dRC deltadrs drs0 Ddist   total_gdppc   Dtrade9601 Dtrade9601lndistpg TP TPlndistpg )  /// 
star(* 0.10 ** 0.05 *** 0.01) se ///
s(Regression N r2 FixedEffects test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat."))

log close

translate "Table4.smcl" "Table4.pdf", replace
translate "Table4.smcl" "Table4.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase temp3.dta
capture erase "Table4.smcl"
