/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 8: testing whether survival of trade flows affects the baseline estimates a la Mulligan and Rubinstein (QJE,2004) */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table6", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs  drs_bw drs_dest drs_source
gen RCIV=(drs-1)*log(distpg)
keep province_code gateway RCIV 
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta"
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) distpg drs  drs_bw drs_dest drs_source, by(province_code gateway period)
sort province_code gateway period

reshape wide distpg drs drs_bw drs_dest drs_source,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs = drs1-drs0

drop distpg0 
sort province_code gateway
save temp2.dta,replace

/* construct dependent variable, change in trade flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

collapse (sum) exp imp,by(province gateway year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow period)
gen lnvalue=ln(value)

reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
drop lnvalue0 lnvalue1
gen lnval0=log(value0)

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6  // see table3.do

gen lndistpg = ln(distpg)
gen dRC      = lndistpg * (deltadrs)

gen D_cont=1 if value1>0 & value0>0
replace D_cont=0 if value1==0 & value0>0

egen fes        = group(province_code flow)
egen fes2       = group(gateway flow)
egen f       = group(flow)

xi:probit D_cont i.province_code i.gateway RCIV lndistpg lnval0 drs0,robust 
estimates store col1
estadd local "FixedEffects" "p,g" , replace
estadd local Regression "Probit" , replace


predict est_prob
pctile pct = est_prob, nq(20) genp(percent)

for X in any  10 25 50 60: gen est_probX=pct if percent==X
for X in any    10 25 50 60: egen m_est_probX=mean(est_probX)
for X in any    10 25 50 60: replace est_probX=m_est_probX
drop m_est_prob*

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons) 
estimates store col2
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local Sample "All" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col2

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) , robust first partial(_cons) , if est_prob>est_prob10 | est_prob==est_prob10
estimates store col3
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local Sample ">10" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if est_prob>est_prob10 | est_prob==est_prob10
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col3

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) , robust first partial(_cons) , if est_prob>est_prob25 | est_prob==est_prob25
estimates store col4
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local Sample ">25" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if est_prob>est_prob25 | est_prob==est_prob25
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) , robust first partial(_cons) , if est_prob>est_prob50 | est_prob==est_prob50
estimates store col5
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local Sample ">50" , replace
estadd scalar test_ar=e(arf): col5
estadd scalar test_kp=e(widstat): col5
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if est_prob>est_prob50 | est_prob==est_prob50
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col5

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) , robust first partial(_cons) , if est_prob>est_prob60 | est_prob==est_prob60
estimates store col6
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local Sample ">60" , replace
estadd scalar test_ar=e(arf): col6
estadd scalar test_kp=e(widstat): col6
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if est_prob>est_prob60 | est_prob==est_prob60
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col6

xi:reg dRC i.fes i.fes2 RCIV lndistpg drs0  if dlnval!=.
predict xhat00
for X in any 10 25 50 60:xi:reg dRC i.fes i.fes2 RCIV lndistpg drs0 if est_prob>est_probX | est_prob==est_probX & dlnval!=. \ predict xhat0X

xi:reg deltadrs i.fes i.fes2 RCIV lndistpg drs0 if dlnval!=.
predict xhat10
for X in any 10 25 50 60:xi:reg dRC i.fes i.fes2 RCIV lndistpg drs0 if est_prob>est_probX | est_prob==est_probX & dlnval!=. \ predict xhat1X


xi:reg dlnval i.fes2 i.fes xhat00 xhat10
est store m0
for X in any 10 25 50 60:xi:reg dlnval i.fes2 i.fes  xhat0X xhat1X if est_prob>est_probX | est_prob==est_probX \ est store mX


suest m10 m25 m50 m60,robust
test [m10_mean ]xhat010=[m25_mean ]xhat025=[m50_mean ]xhat050=[m60_mean ]xhat060 
estadd scalar test_su=r(chi2): col6
estadd scalar test_su_p =r(p): col6

noi display "****************************"
noi display "****************************"
noi display " "
noi display "Results"

noi esttab col1 col2 col3 col4  col5 col6, compress width(1\hsize) ///
keep( dRC lnval0  deltadrs lndistpg RCIV drs0)  /// 
 se star(* 0.10 ** 0.05 *** 0.01) s(Regression Sample N r2 FixedEffects test_ar test_kp test_DWH test_su test_su_p)
 
/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable D_cont "$Prob(trade_{pg,2012}^f>0|trade_{pg,2012}^f>0)$"
label variable lndistpg "$\ln dist_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable RCIV "$(\ers_{pg}^{2003}-1)\times\ln dist_{pg}$"
label variable drs0 "$(\ers_{pg}^{2003}$"
label variable lnval0 "$\ln trade_{pg,2003}^f$"

esttab col1 col2 col3 col4  col5 col6 using "Table6.tex", replace label  compress width(1\hsize) keep( dRC lnval0  deltadrs lndistpg RCIV drs0)  se star(* 0.10 ** 0.05 *** 0.01) s(Regression Sample N r2 FixedEffects test_ar test_kp test_DWH test_su, label("Regression" "Sample" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat." "SUR Test Stat."))
}

log close

translate "Table6.smcl" "Table6.pdf",replace
translate "Table6.smcl" "Table6.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase "Table6.smcl"

 

