/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 7: new trade links: extensive margin */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table7", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs drs_bw drs_dest drs_source
gen RCIV    = (drs-1)*log(distpg) // instrumental variable
gen RCIV_bw = (drs_bw-1)*log(distpg)
keep province_code gateway RCIV RCIV_bw
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) distpg drs  drs_bw, by(province_code gateway period)
sort province_code gateway period
reshape wide distpg drs drs_bw ,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs         = drs1-drs0
gen deltadrs_bw      = drs_bw1-drs_bw0
drop distpg0 drs_bw1 drs1
sort province_code gateway
save temp2.dta,replace

/*Gravity estimation to construct the market access and supply access measures */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace
keep if year==2003
drop year

collapse (sum) exp imp,by(province gateway )

rename exp value1
rename imp value2
reshape long value, i( province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order  province gate flow
sort  province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow  gateway province
replace value=0 if value==.

collapse (mean) value, by(province_code gateway flow)

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)

sort province_code flow
by province_code flow:egen exp_cf=sum(value)
drop if exp_cf==0

egen fes        = group(province_code flow )
egen fes2       = group(gateway flow)

tab fes,gen(fesdum)
tab fes2,gen(fes2dum)

// estimate fixed effects from gravity to construct trade potential of cities
ppml value fesdum* fes2dum* lndistpg
gen fe_est_p=. 
for X in num 1/159: replace fe_est_p=_b[fesdumX] if fesdumX==1  
gen fe_est_g=. 
for X in num 1/34: replace fe_est_g=_b[fes2dumX] if fes2dumX==1  

gen ma_pg=(exp(fe_est_g))*(distpg^_b[lndistpg]) 
gen sa_pg=(exp(fe_est_p))*(distpg^_b[lndistpg])

sort province_code
by province_code: egen ma_p=sum(ma_pg)
sort gateway
by gateway: egen sa_g=sum(sa_pg)

gen TP = (ma_p*sa_g)

keep province_code gateway flow TP
sort province_code gateway flow
save temp3.dta,replace

/* construct dependent variable, change in flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR" // trade with Turkish Cyprotic Republic
drop if year==.
destring province_code,replace
destring gateway,replace
collapse (sum) exp imp,by(province gateway year)
rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) value, by(province_code gateway flow period)
reshape wide value,i(province_code gateway flow) j(period)

replace value0=0 if value0==.
replace value1=0 if value1==.
gen D_newgate=1 if value1>0 & value0==0
replace D_newgate=0 if D_newgate==.
drop value0 value1

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

/* Additional controls */
// percapita income change in the route 
merge m:1 province_code gateway using "data/routes_gdppc.dta"
drop if _merge==2
drop _merge
// trade change in the route 
merge m:1 province_code gateway using "data/routes_trade_pre.dta"
drop if _merge==2
drop _merge

// market access+supply access 
sort province_code gateway flow
merge province_code gateway flow  using "temp3.dta"
drop _merge

drop if gateway==6 

gen lndistpg        = ln(distpg)
gen dRC             = lndistpg * (deltadrs)
gen dRC_bw          = lndistpg * (deltadrs_bw)

replace total_gdppc=0 if total_gdppc==.
gen Dtrade9601  = ln(total_trade01)-ln(total_trade96)
replace Dtrade9601=0 if Dtrade9601==.

su distpg,det
gen Ddist=distpg>r(p50) 

gen Dtrade9601lndistpg  = Dtrade9601*lndistpg
gen TPlndistpg          = TP*lndistpg

rename province_code city
drop distpg 

egen fes        = group(city flow)    // fixed effects
egen fes2       = group(gateway flow)

/**************/
// Regressions
/**************/

xi:ivreg2 D_newgate i.fes2 i.fes (dRC = RCIV lndistpg) , robust first partial(_cons)
estimates store col1
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col1
estadd scalar test_kp=e(widstat): col1
xi:ivreg D_newgate i.fes2 i.fes (dRC = RCIV lndistpg) 
ivendog dRC
estadd scalar test_DWH=r(WHF): col1

xi:ivreg2 D_newgate i.fes2 i.fes (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col2
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg D_newgate i.fes2 i.fes (dRC deltadrs= RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col2

xi:ivreg2 D_newgate i.fes2 i.fes (dRC_bw deltadrs_bw= RCIV_bw lndistpg drs_bw0) , robust first partial(_cons)
estimates store col3
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg D_newgate i.fes2 i.fes (dRC_bw deltadrs_bw= RCIV_bw lndistpg drs_bw0) 
ivendog dRC_bw deltadrs_bw
estadd scalar test_DWH=r(WHF): col3

xi:ivreg2 D_newgate i.fes2 i.fes  Ddist (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col4
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg D_newgate i.fes2 i.fes  Ddist (dRC deltadrs = RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4

xi:ivreg2 D_newgate i.fes2 i.fes Ddist  total_gdppc (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col5
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col5
estadd scalar test_kp=e(widstat): col5
xi:ivreg D_newgate i.fes2 i.fes Ddist Dtrade9601 total_gdppc TP (dRC deltadrs = RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col5

xi:ivreg2 D_newgate i.fes2 i.fes Ddist  total_gdppc Dtrade9601 Dtrade9601lndistpg TP  TPlndistpg (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col6
estadd local "FixedEffects" "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col6
estadd scalar test_kp=e(widstat): col6
xi:ivreg D_newgate i.fes2 i.fes Ddist Dtrade9601 total_gdppc TP (dRC deltadrs = RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col6

/**************/
// Results
/**************/
noi esttab col1 col2 col3 col4 col5 col6, compress width(1\hsize) ///
keep( dRC dRC_bw deltadrs deltadrs_bw Ddist total_gdppc Dtrade9601 Dtrade9601lndistpg TP  TPlndistpg)  /// 
star(* 0.10 ** 0.05 *** 0.01) se s(Regression N r2 FixedEffects test_ar test_kp test_DWH)

/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable lndistpg "$\ln dist_{pg}$"
label variable D_newgate "$\New_{pg}^f$"
label variable dRC_bw "$\Delta RC^{bw}_{pg}$"
label variable RCIV "$(\ers_{pg}^{2003}-1)\times\ln dist_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable drs0 "$\ers_{pg}^{2003}$"
label variable total_gdppc "$\Delta \ln PGDP_{pg}^{04-11}$"
label variable Dtrade9601 "$\Delta \ln trade_{pg}^{96-01}$"
label variable TP "$\ln(\MA_p + SA_g)$"
label variable Ddist "$I_{dist_{pg}>median}$"
label variable Dtrade9601lndistpg "$\Delta \ln trade_{pg}^{96-01}\times \ln dist_{pg}$"
label variable TPlndistpg "$(\MA_p \times SA_g)\times \ln dist_{pg}$"

esttab col1 col2 col3 col4 col5 col6 using "table7.tex",replace label compress width(1\hsize) ///
keep( dRC dRC_bw deltadrs deltadrs_bw Ddist total_gdppc Dtrade9601 Dtrade9601lndistpg TP  TPlndistpg)  /// 
star(* 0.10 ** 0.05 *** 0.01) se ///
s(Regression N r2 FixedEffects test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat."))
}

log close

translate "Table7.smcl" "Table7.pdf",replace
translate "Table7.smcl" "Table7.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase temp3.dta
capture erase "Table7.smcl"
