/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 9: decomposition of trade increase into extensive and intensive margins in terms of gateways, industries and trade partners */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table8", replace

qui{
/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs 
gen RCIV=(drs-1)*log(distpg)
keep province_code gateway RCIV 
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta"
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) distpg drs , by(province_code gateway period)
sort province_code gateway period

reshape wide distpg drs,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs = drs1-drs0
drop distpg0 
sort province_code gateway
save temp2.dta,replace

/******************************************************************************************************/
/* Decomposition of pg trade increase into intensive and extensive margins of trade partner countries */
/******************************************************************************************************/
use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

gen period =.
replace period=0 if year<`yearbeg' 
replace period=1 if year>`yearend' 
drop if period ==.


sort  province gateway year wbcode
by  province gateway year wbcode: gen numcountry1 = _n==1  if exp_pgd>0 
by  province gateway year : replace numcountry1 =sum(numcountry1)
by  province gateway year : replace numcountry1 =numcountry1[_N]

by  province gateway year wbcode: gen numcountry2 = _n==1 if imp_pgd>0 
by  province gateway year : replace numcountry2 =sum(numcountry2)
by  province gateway year : replace numcountry2 =numcountry2[_N]

collapse (sum) exp imp (mean) numcountry1 numcountry2,by(province gateway year)

rename exp value1
rename imp value2
reshape long value numcountry, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.
sort province gateway flow year

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value numcountry, by(province_code gateway flow period)
gen lnvalue=ln(value)
gen lnnumcountry=ln(numcountry)
drop value numcountry

reshape wide  lnvalue lnnumcountry,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
gen extensive= lnnumcountry1-lnnumcountry0
gen intensive= dlnval-extensive
drop if dlnval==.
drop if extensive==.

drop lnvalue0 lnvalue1 lnnumcountry1 lnnumcountry0

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)
gen dRC = lndistpg * (deltadrs)

rename province_code city

egen fes        = group(city flow)
egen fes2       = group(gateway flow)

// Regressions

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0) , robust first  partial(_cons)
estimates store col1
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Total"  , replace
estadd scalar test_ar=e(arf): col1
estadd scalar test_kp=e(widstat): col1
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col1

xi:ivreg2 intensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0) , robust first  partial(_cons)
estimates store col2
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Intensive-cty" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg intensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col2

xi:ivreg2 extensive i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col3
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Extensive-cty" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg extensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col3

/****************************************************************************************/
/* Decomposition of pg trade increase into intensive and extensive margins of industries */
/****************************************************************************************/
clear
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

use "data/data_pgi.dta",clear
destring province_code,replace
destring gateway,replace
rename isic3_2 ind

gen period =.
replace period=0 if year<`yearbeg' 
replace period=1 if year>`yearend' 
drop if period ==.


sort  province gateway year ind
by  province gateway year ind: gen numind1 = _n==1 if  exp_pgi>0 
by  province gateway year : replace numind1 =sum(numind1) 
by  province gateway year : replace numind1 =numind1[_N]

sort  province gateway year ind
by  province gateway year ind: gen numind2 = _n==1 if  imp_pgi>0 
by  province gateway year : replace numind2 =sum(numind2)
by  province gateway year : replace numind2 =numind2[_N]


collapse (mean) numind1 numind2,by(province gateway year)
reshape long numind, i(year province gateway) j(flow)

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

drop year

sort province gateway flow period
save temp3.dta,replace

use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

rename exp_pgd value1
rename imp_pgd value2

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (sum) value1 value2 ,by(province gateway period)
reshape long value, i( province gateway period) j(flow)

sort  province gateway flow period
merge province gateway flow period using temp3.dta
drop _merge

gen lnvalue=ln(value)
gen lnnumind=ln(numind)
drop value numind

reshape wide lnvalue lnnumind,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
gen extensive  = lnnumind1-lnnumind0
gen intensive  = dlnval-extensive
drop if dlnval==.
drop if extensive==.

drop lnvalue0 lnvalue1 lnnumind1 lnnumind0

sort province_code gateway
merge province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)
gen dRC      = lndistpg * (deltadrs)

rename province_code city

egen fes        = group(city flow)
egen fes2       = group(gateway flow)

// Regressions

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0) , robust  first partial(_cons)
estimates store col4
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Total"  , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4

xi:ivreg2 intensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) , robust first  partial(_cons)
estimates store col5
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Intensive-ind" , replace
estadd scalar test_ar=e(arf): col5
estadd scalar test_kp=e(widstat): col5
xi:ivreg intensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col5

xi:ivreg2 extensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) , robust first partial(_cons), if dlnval!=.
estimates store col6
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Extensive-ind" , replace
estadd scalar test_ar=e(arf): col6
estadd scalar test_kp=e(widstat): col6
xi:ivreg extensive i.fes2 i.fes  (dRC deltadrs = RCIV lndistpg drs0 ) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col6

noi display "****************************"
noi display "****************************"
noi display " "

noi esttab col1 col2 col3 col4  col5 col6, compress width(1\hsize) ///
keep( dRC  deltadrs) se star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects margin test_ar test_kp test_DWH)

/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable extensive "$\Delta \ln N_{pg}^f$"
label variable intensive "$\Delta \ln(trade_{pg}^f/N_{pg}^f)$"

esttab col1 col2 col3 col4  col5 col6 using "table8.tex",replace label compress width(1\hsize) ///
keep( dRC deltadrs) star(* 0.10 ** 0.05 *** 0.01) se ///
s(Regression N r2 FixedEffects margin test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "Margin"  "AR Test Stat." "KP Test Stat." "DWH Test Stat."))

}

log close  

translate "Table8.smcl" "Table8.pdf",replace
translate "Table8.smcl" "Table8.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase temp3.dta
capture erase "Table8.smcl"

