/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 7: results separetely for exports and imports without pooling */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table9", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs 
gen RCIV=(drs-1)*log(distpg)
keep province_code gateway RCIV 
sort province_code gateway
save temp2.dta,replace

use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) distpg drs , by(province_code gateway period)
sort province_code gateway period

reshape wide distpg drs,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs = drs1-drs0

drop distpg0 
sort province_code gateway
save temp.dta,replace

use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

collapse (sum) exp imp,by(province gateway year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow period)
gen lnvalue=ln(value)

reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
drop lnvalue0 lnvalue1

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)
gen dRC      = lndistpg * (deltadrs)

drop if dlnval==.
by province_code gateway, sort: gen numobs_pg=_N
keep if numobs_pg==2

rename province_code city

egen fes        = group(city)
egen fes2       = group(gateway)

/**************/
// Regressions
/**************/

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons)
estimates store col1
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Intensive" , replace
estadd local sample "All" , replace
estadd scalar test_ar=e(arf): col1
estadd scalar test_kp=e(widstat): col1
xi:ivreg dlnval i.fes2 i.fes  ( dRC deltadrs= RCIV lndistpg drs0) if flow=="exp" 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col1

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons),if flow=="exp" 
estimates store col2
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Intensive" , replace
estadd local sample "Export" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg dlnval i.fes2 i.fes  ( dRC deltadrs= RCIV lndistpg drs0) if flow=="exp" 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col2

xi:ivreg2 dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons),if flow=="imp" 
estimates store col3
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Intensive" , replace
estadd local sample "Import" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg dlnval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) if flow=="imp" 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col3

*************************************
*Extensive margin
*************************************

use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

collapse (sum) exp imp,by(province gateway year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow period)
gen lnvalue=ln(value)

reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen D_newgate=1 if value1>0 & value0==0
replace D_newgate=0 if D_newgate==.
gen dlnval     = lnvalue1-lnvalue0

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99

drop if gateway==6 

gen lndistpg = ln(distpg)
gen dRC      = lndistpg * (deltadrs)


rename province_code city

egen fes        = group(city)
egen fes2       = group(gateway)



xi:ivreg2 D_newgate i.fes2 i.fes   (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons) ,if flow=="exp"
estimates store col4
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Extensive" , replace
estadd local sample "Export" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg D_newgate i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if flow=="exp" 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4


xi:ivreg2 D_newgate i.fes2 i.fes   (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons) ,if flow=="imp"
estimates store col5
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd local margin "Extensive" , replace
estadd local sample "Import" , replace
estadd scalar test_ar=e(arf): col5
estadd scalar test_kp=e(widstat): col5
xi:ivreg D_newgate i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0 ) if flow=="imp" 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col5



noi display "****************************"
noi display "****************************"
noi display " "
noi display "Results"

 noi esttab col1 col2 col3 col4 col5, compress width(1\hsize) ///
keep( dRC deltadrs ) se star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 sample FixedEffects margin)

/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable D_newgate "$\New_{pg}^f)$"

esttab col1 col2 col3 col4 col5 using "Table9.tex", replace label compress width(1\hsize) ///
keep( dRC  deltadrs) se star(* 0.10 ** 0.05 *** 0.01) ///
s(Regression N r2 sample margin FixedEffects test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Flow" "Margin" ///
 "Fixed Effects" "AR Test Stat." "KP Test Stat."  "DWH Test Stat."))

}
log close

translate "Table9.smcl" "Table9.pdf",replace
translate "Table9.smcl" "Table9.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase "Table9.smcl"



