/* Cosar-Demir, Domestic road infrastructure and international trade, JDE revised version
Figures 3 & 4 */

clear all
set more off
log close _all
set matsize 5000
                                                                    
if "`c(username)'" == "kcosar" & "`c(os)'"  =="MacOSX" cd "/Users/kcosar/Dropbox/Research/CosarDemirPakel-ExpTransport/Data/do files/dofiles_JDE_0415/jde_finalround"
if "`c(username)'" == "kcosar" & "`c(os)'"  !="MacOSX" cd "C:\Dropbox\Research\CosarDemirPakel-ExpTransport\Data\do files\dofiles_JDE_0415\jde_finalround"
if "`c(username)'" == "ACER-PC" cd "C:\Users\ACER-PC\Dropbox\CosarDemirPakel-ExpTransport\Data\do files\dofiles_JDE_0415\jde_finalround"
if "`c(username)'" == "banudemir" cd "/Users/banudemir/Dropbox/CosarDemirPakel-ExpTransport/Data/do files/dofiles_JDE_0415/jde_finalround"

/******************************************************************************************/
/* Figure 2: Long term perspective 
source: www.tuik.gov.tr/PreIstatistikTablo.do?istab_id=1585*/
cd ..
cd ..
cd ..
cd ..
use "Data\TUIK_data\tuik_roaddata_longterm_general.dta", clear
gen doubleroads=expressway+highway

replace doubleroads =doubleroads/1000
replace totalroads  =totalroads/1000

label variable doubleroads "Expressways"
label variable totalroads "Total road stock"

tw (line totalroads  year,  lwidth(1.3) ytitle("1000 Kilometers", height(5)) ylabel(0(5)70, angle(horizontal)) xlabel(1984(2)2012) xtitle("") plotregion(fcolor(white)) graphregion(fcolor(white)) name(panela, replace)) ///
(line doubleroads year, xline(2002,lpattern("dash") lwidth(0.1)) lpattern("dash") lwidth(1.3) ylabel(0(5)70, angle(horizontal)) xlabel(1984(2)2012,angle(45)) xtitle("")) 

/* Figure 3: change in trade to change in ers to Istanbul -- visualizing the variation */
clear all
local yearbeg  = "2005" // cutoff years for long-term differences
local yearend  = "2010"

/* change in road capacity */
use "data/market_access_pg.dta"  

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

rename drs rq

collapse (mean) distpg rq, by(province_code gateway period)
sort province_code gateway period

reshape wide distpg rq,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs =rq1-rq0
drop distpg0 


gen lndistpg = ln(distpg)

sort province_code gateway
save temp.dta,replace

use "data/data_pgd.dta",clear
drop if wbcode=="TUR"
drop if year==.
destring province_code,replace
destring gateway,replace

collapse (sum) exp imp,by(province gateway year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99
drop if province_code==0 | province_code==99

drop if gateway==6  // Ankara

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code  gateway period)
reshape wide value ,i(province_code gateway) j(period)

by province_code ,sort: egen value_p0=sum(value0) //total exports of p in the initial period
replace value0=0 if value0==.
gen shr_p0=value0/value_p0 // share of g in p's total trade in the initial period

sort province_code  gateway
merge province_code gateway  using temp.dta
drop if _merge==2
drop _merge

gen dval=log(value1)-log(value0)
xi: areg dval i.gateway,absorb(province_code)
predict dval_res,residuals

replace deltadrs=deltadrs*shr_p0 // *lndistpg
replace dval= dval_res *shr_p0 

collapse (sum) deltadrs dval ,by(province_code)


rename province_code city
rename dval Chg_ltrade
rename deltadrs Chg_ers

regress Chg_ltrade Chg_ers
local coef : di %7.3f _b[Chg_ers]
local se : di %7.3f _se[Chg_ers]

graph twoway (lfitci Chg_ltrade Chg_ers) ///
(scatter Chg_ltrade Chg_ers), ///
legend(row(2) order(- "Slope: `coef'" - "St.Err.:`se'") size(4) ring(0) pos(4)) /// 
plotregion(fcolor(white)) graphregion(fcolor(white)) ///
ytitle("Change in ln(Trade)") ///
xtitle("Change in Weighted ers")

graph save Graph "ChgTradeERS.gph", replace
graph export "ChgTradeERS.eps", replace

capture erase "ChgTradeERS.gph"
capture erase temp.dta
capture erase share.dta

/******************************************************************************************/
/* Figure 4: change in expressway road share to initial ers -- visualizing the instrument */
clear
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) drs , by(province_code gateway period)
sort province_code gateway period

reshape wide drs,i(province_code gateway) j(period)
gen deltadrs = drs1-drs0

rename deltadrs Chg_ers
rename drs0 ers_0

regress Chg_ers ers_0
local coef : di %7.3f _b[ers_0]
local se : di %7.3f _se[ers_0]

graph twoway (lfit  Chg_ers ers_0, legend(ring(0) pos(2) order(1) rows(1)))  ///
(scatter Chg_ers ers_0, msize(small) ///
legend(row(2) order(- "Slope: `coef'" - "St.Err.:`se'") size(4) ring(0) pos(1)) /// 
ytitle("Change in ers", height(5)) xtitle("Initial ers") ///
plotregion(fcolor(white)) graphregion(fcolor(white)))

graph save Graph "ChgERS.gph", replace
graph export "ChgERS.eps", replace
capture erase "ChgERS.gph"
